#include<iostream>
#include<vector>
#include<cmath>
using namespace std;

const double ERROR = 0.0000001;

struct Vec {
    double x, y;
    
    Vec(double nx = 0.0, double ny = 0.0) {
        x = nx;
        y = ny;
    }
    
    Vec& operator+=(Vec r) {
        x += r.x;
        y += r.y;
        return *this;
    }
    Vec operator+(Vec r) {return Vec(*this) += r;}
    
    Vec& operator-=(Vec r) {
        x -= r.x;
        y -= r.y;
        return *this;
    }
    Vec operator-(Vec r) {return Vec(*this) -= r;}
    
    Vec& operator*=(double r) {
        x *= r;
        y *= r;
        return *this;
    }
    Vec operator*(double r) {return Vec(*this) *= r;}
    
    double operator*(Vec r) {
        return x*r.x + y*r.y;
    }
};

double cprod(Vec l, Vec r) {
    return l.x*r.y - l.y*r.x;
}

double len(Vec l) {
    return hypot(l.x, l.y);
}

Vec intersect(Vec A, Vec B, Vec C, Vec D) {
    Vec a = B-A;
    Vec b = D-C;
    if(len(b) == 0) throw 1;
    
    double h = cprod(b, C-A) / len(b);
    double h_d = cprod(b, a) / len(b);
    if(h_d == 0) throw 1;
    
    Vec X = A + a * (h/h_d);
    return X;
}

bool in_segment(Vec A, Vec B, Vec C) {
    Vec a = B-A;
    Vec b = C-A;
    double d = b * a / len(a);
    
    return d > -ERROR && d <= len(a) + ERROR;
}

int main() {
    // Vec X = intersect(Vec(3, 3), Vec(7, 4), Vec(1, 4), Vec(2, 8));
    // cout << X.x << ' ' << X.y << '\n';
    
    int q;
    cin >> q;
    
    for(int i=0; i<q; i++) {
        Vec A, B, C, D;
        cin >> A.x >> A.y >> B.x >> B.y >> C.x >> C.y >> D.x >> D.y;
        
        try {
            Vec X = intersect(A, B, C, D);
            if(in_segment(A, B, X) && in_segment(C, D, X)) {
                cout << "JAH\n";
            } else {
                cout << "EI\n";
            }
        } catch(...) {
            cout << "EI\n";
        }
    }
    return 0;
}