#include<iostream>
#include<vector>
#include<cmath>
#include<string>
#include<fstream>
using namespace std;

const double ERROR = 0.0000001;

struct Vec {
    double x, y;
    
    Vec(double nx = 0.0, double ny = 0.0) {
        x = nx;
        y = ny;
    }
    
    Vec& operator+=(Vec r) {
        x += r.x;
        y += r.y;
        return *this;
    }
    Vec operator+(Vec r) {return Vec(*this) += r;}
    
    Vec& operator-=(Vec r) {
        x -= r.x;
        y -= r.y;
        return *this;
    }
    Vec operator-(Vec r) {return Vec(*this) -= r;}
    
    Vec& operator*=(double r) {
        x *= r;
        y *= r;
        return *this;
    }
    Vec operator*(double r) {return Vec(*this) *= r;}
    
    double operator*(Vec r) {
        return x*r.x + y*r.y;
    }
};

double cprod(Vec l, Vec r) {
    return l.x*r.y - l.y*r.x;
}

double len(Vec l) {
    return hypot(l.x, l.y);
}

double get_area(vector<Vec> poly) {
    double result = 0;
    for(int i=0; i<(int)poly.size(); i++) {
        int j = (i+1)%(poly.size());
        result += cprod(poly[i], poly[j] - poly[i]) / 2.0;
    }
    return abs(result);
}


int main() {
    ifstream in("pindgsis.txt");
    ofstream out("pindgval.txt");
    vector<Vec> poly = {0, 0};
    Vec cur = {0, 0};
    
    int k;
    string s;
    in >> k >> s;
    
    for(auto c : s) {
        if(c == 'N') {
            cur += Vec(0, 1);
        }
        if(c == 'E') {
            cur += Vec(1, 0);
        }
        if(c == 'S') {
            cur += Vec(0, -1);
        }
        if(c == 'W') {
            cur += Vec(-1, 0);
        }
        poly.push_back(cur);
    }
    double result = get_area(poly);
    out << (long long)round(result) << '\n';
    return 0;
}