#include<iostream>
#include<vector>
#include<cmath>
#include<string>
#include<fstream>
#include<algorithm>
#include<iomanip>
using namespace std;

const double ERROR = 0.0000001;

struct Vec {
    double x, y;
    
    Vec(double nx = 0.0, double ny = 0.0) {
        x = nx;
        y = ny;
    }
    
    Vec& operator+=(Vec r) {
        x += r.x;
        y += r.y;
        return *this;
    }
    Vec operator+(Vec r) {return Vec(*this) += r;}
    
    Vec& operator-=(Vec r) {
        x -= r.x;
        y -= r.y;
        return *this;
    }
    Vec operator-(Vec r) {return Vec(*this) -= r;}
    
    Vec& operator*=(double r) {
        x *= r;
        y *= r;
        return *this;
    }
    Vec operator*(double r) {return Vec(*this) *= r;}
    
    double operator*(Vec r) {
        return x*r.x + y*r.y;
    }
    
    bool operator<(Vec r) const {
        if(y != r.y) return y < r.y;
        return x < r.x;
    }
};

double cprod(Vec l, Vec r) {
    return l.x*r.y - l.y*r.x;
}

double len(Vec l) {
    return hypot(l.x, l.y);
}

Vec base;
double get_angle(Vec a) {
    return atan2(a.y, a.x);
}
bool by_angle(Vec l, Vec r) {
    return get_angle(l-base) < get_angle(r-base);
}

vector<Vec> get_hull(vector<Vec> poly) {
    sort(poly.begin(), poly.end());
    vector<Vec> hull = {poly[0]};
    base = poly[0];
    
    sort(poly.begin()+1, poly.end(), by_angle);
    for(int i=1; i<(int)poly.size(); i++) {
        int n = hull.size();
        hull.push_back(poly[i]);
        
        while(n > 1 && cprod(hull[n-1] - hull[n-2], hull[n] - hull[n-1]) <= 0) {
            swap(hull[n], hull[n-1]);
            hull.pop_back();
            n--;
        }
    }
    return hull;
}


int main() {
    int n;
    vector<Vec> poly;
    
    cin >> n;
    for(int i=0; i<n; i++) {
        Vec cur;
        cin >> cur.x >> cur.y;
        poly.push_back(cur);
    }
    
    vector<Vec> hull = get_hull(poly);
    double result = 0.0;
    for(int i=0; i<(int)hull.size(); i++) {
        int j = (i+1) % (hull.size());
        result += len(hull[j] - hull[i]);
    }
    cout << fixed << setprecision(6) << result << '\n';
    return 0;
}